==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/d5/d62/industrytype_8h.js <==
var industrytype_8h =
[
    [ "IndustryTileTable", "d1/db5/structIndustryTileTable.html", "d1/db5/structIndustryTileTable" ],
    [ "IndustrySpec", "db/d4c/structIndustrySpec.html", "db/d4c/structIndustrySpec" ],
    [ "IndustryTileSpec", "d9/d21/structIndustryTileSpec.html", "d9/d21/structIndustryTileSpec" ],
    [ "CheckProc", "d5/d62/industrytype_8h.html#a54363dfab2318e7d24fa83b0666b312b", [
      [ "CHECK_NOTHING", "d5/d62/industrytype_8h.html#a54363dfab2318e7d24fa83b0666b312bacc607ecdcaf7ac10836498ac1c32b6fc", null ],
      [ "CHECK_FOREST", "d5/d62/industrytype_8h.html#a54363dfab2318e7d24fa83b0666b312baaaea95595ada9815e80802a632392164", null ],
      [ "CHECK_REFINERY", "d5/d62/industrytype_8h.html#a54363dfab2318e7d24fa83b0666b312ba058481b5fe16cad7dae9af8aa23db022", null ],
      [ "CHECK_FARM", "d5/d62/industrytype_8h.html#a54363dfab2318e7d24fa83b0666b312bab7c5bb91757770d4bbc113689faedc70", null ],
      [ "CHECK_PLANTATION", "d5/d62/industrytype_8h.html#a54363dfab2318e7d24fa83b0666b312ba0b84b07949e9dd6da3cb755e8daa63c6", null ],
      [ "CHECK_WATER", "d5/d62/industrytype_8h.html#a54363dfab2318e7d24fa83b0666b312ba7a22197324a2bbae6b3234445c149d68", null ],
      [ "CHECK_LUMBERMILL", "d5/d62/industrytype_8h.html#a54363dfab2318e7d24fa83b0666b312ba73090eaa29a15f6776c0b76cd525d62a", null ],
      [ "CHECK_BUBBLEGEN", "d5/d62/industrytype_8h.html#a54363dfab2318e7d24fa83b0666b312ba9829645d52d8361f20f26ce6f329e66d", null ],
      [ "CHECK_OIL_RIG", "d5/d62/industrytype_8h.html#a54363dfab2318e7d24fa83b0666b312ba3271c3e72eefaac6d8a43a782732b1d2", null ],
      [ "CHECK_END", "d5/d62/industrytype_8h.html#a54363dfab2318e7d24fa83b0666b312ba0b35eb6fd6cfa60b8000413f5962dd26", null ]
    ] ],
    [ "IndustryBehaviour", "d5/d62/industrytype_8h.html#a99a00afbb745b5044eadcb3211e8e2f9", [
      [ "INDUSTRYBEH_NONE", "d5/d62/industrytype_8h.html#a99a00afbb745b5044eadcb3211e8e2f9a5cc5dba847782c7648a951c34bc593d0", null ],
      [ "INDUSTRYBEH_PLANT_FIELDS", "d5/d62/industrytype_8h.html#a99a00afbb745b5044eadcb3211e8e2f9a76dde7b7f789ec2009577aa97c14ff3e", null ],
      [ "INDUSTRYBEH_CUT_TREES", "d5/d62/industrytype_8h.html#a99a00afbb745b5044eadcb3211e8e2f9a6d58133a80e93e1df5af1da431c713f8", null ],
      [ "INDUSTRYBEH_BUILT_ONWATER", "d5/d62/industrytype_8h.html#a99a00afbb745b5044eadcb3211e8e2f9a72a2551a3aebb49f26b79c4082444919", null ],
      [ "INDUSTRYBEH_TOWN1200_MORE", "d5/d62/industrytype_8h.html#a99a00afbb745b5044eadcb3211e8e2f9a907ddb055343a0f53899bf5cde042698", null ],
      [ "INDUSTRYBEH_ONLY_INTOWN", "d5/d62/industrytype_8h.html#a99a00afbb745b5044eadcb3211e8e2f9a9c81cbddfddaf0014021ec17ed4ea125", null ],
      [ "INDUSTRYBEH_ONLY_NEARTOWN", "d5/d62/industrytype_8h.html#a99a00afbb745b5044eadcb3211e8e2f9a8c2180317b5afe82e96461252c77fbbf", null ],
      [ "INDUSTRYBEH_PLANT_ON_BUILT", "d5/d62/industrytype_8h.html#a99a00afbb745b5044eadcb3211e8e2f9a406a478ad0065a3ac1bc7bcce6c39d7d", null ],
      [ "INDUSTRYBEH_DONT_INCR_PROD", "d5/d62/industrytype_8h.html#a99a00afbb745b5044eadcb3211e8e2f9a39109885917fedb779ff2a8a93aedd6c", null ],
      [ "INDUSTRYBEH_BEFORE_1950", "d5/d62/industrytype_8h.html#a99a00afbb745b5044eadcb3211e8e2f9aa050bdda302a8fad2713a5bb62577663", null ],
      [ "INDUSTRYBEH_AFTER_1960", "d5/d62/industrytype_8h.html#a99a00afbb745b5044eadcb3211e8e2f9a6abc825a855b53a48515a5d3e0a1bf01", null ],
      [ "INDUSTRYBEH_AI_AIRSHIP_ROUTES", "d5/d62/industrytype_8h.html#a99a00afbb745b5044eadcb3211e8e2f9ab62ae5c5a95e0377c6bfa2910c4cad9f", null ],
      [ "INDUSTRYBEH_AIRPLANE_ATTACKS", "d5/d62/industrytype_8h.html#a99a00afbb745b5044eadcb3211e8e2f9a1f43d132d3c437a41e80dbdaf2e8bd79", null ],
      [ "INDUSTRYBEH_CHOPPER_ATTACKS", "d5/d62/industrytype_8h.html#a99a00afbb745b5044eadcb3211e8e2f9a2f157fd12c1e0c258cc70ab4a0f6a7cf", null ],
      [ "INDUSTRYBEH_CAN_SUBSIDENCE", "d5/d62/industrytype_8h.html#a99a00afbb745b5044eadcb3211e8e2f9a0347d41faf719458cfa73c39eab6a2c7", null ],
      [ "INDUSTRYBEH_PROD_MULTI_HNDLING", "d5/d62/industrytype_8h.html#a99a00afbb745b5044eadcb3211e8e2f9a0237a5e8759779257383a9f21673ef34", null ],
      [ "INDUSTRYBEH_PRODCALLBACK_RANDOM", "d5/d62/industrytype_8h.html#a99a00afbb745b5044eadcb3211e8e2f9a5c8855dc4b542e13ad6fb1262d1f223f", null ],
      [ "INDUSTRYBEH_NOBUILT_MAPCREATION", "d5/d62/industrytype_8h.html#a99a00afbb745b5044eadcb3211e8e2f9adee9047f79a24111a338955e2ec2bb02", null ],
      [ "INDUSTRYBEH_CANCLOSE_LASTINSTANCE", "d5/d62/industrytype_8h.html#a99a00afbb745b5044eadcb3211e8e2f9a8403a7641291b2a97cbf819f605e79f6", null ],
      [ "INDUSTRYBEH_CARGOTYPES_UNLIMITED", "d5/d62/industrytype_8h.html#a99a00afbb745b5044eadcb3211e8e2f9a4f7c1634fba42ab82a3547a591171be2", null ]
    ] ],
    [ "IndustryCleanupType", "d5/d62/industrytype_8h.html#a27c1fa18b6703e4d2c30dc686af62178", [
      [ "CLEAN_RANDOMSOUNDS", "d5/d62/industrytype_8h.html#a27c1fa18b6703e4d2c30dc686af62178a421b15b0bf55b443317d203ac6e89dc3", null ],
      [ "CLEAN_TILELAYOUT", "d5/d62/industrytype_8h.html#a27c1fa18b6703e4d2c30dc686af62178a75b0fac8bdc81bc54d9d3edc40f1ef02", null ]
    ] ],
    [ "IndustryConstructionType", "d5/d62/industrytype_8h.html#a40770aa0e81a963e9e68382bbeea78f0", [
      [ "ICT_UNKNOWN", "d5/d62/industrytype_8h.html#a40770aa0e81a963e9e68382bbeea78f0a087b3ea80e3cbe71eb40d01e67a0cf29", null ],
      [ "ICT_NORMAL_GAMEPLAY", "d5/d62/industrytype_8h.html#a40770aa0e81a963e9e68382bbeea78f0a4cfe1db4597262af6495f9ad991f5299", null ],
      [ "ICT_MAP_GENERATION", "d5/d62/industrytype_8h.html#a40770aa0e81a963e9e68382bbeea78f0a38cc494ebad39e571b0bb076c7a5dad9", null ],
      [ "ICT_SCENARIO_EDITOR", "d5/d62/industrytype_8h.html#a40770aa0e81a963e9e68382bbeea78f0aa81941c1ebe098b7f56d5738ba7c55af", null ]
    ] ],
    [ "IndustryLifeType", "d5/d62/industrytype_8h.html#a061cabddf1f472aa0b20fc1c827b1a34", [
      [ "INDUSTRYLIFE_BLACK_HOLE", "d5/d62/industrytype_8h.html#a061cabddf1f472aa0b20fc1c827b1a34accef54b0e1b27f14e41048ab775ae8f1", null ],
      [ "INDUSTRYLIFE_EXTRACTIVE", "d5/d62/industrytype_8h.html#a061cabddf1f472aa0b20fc1c827b1a34a744b53cf47148684f40de047a727ef1e", null ],
      [ "INDUSTRYLIFE_ORGANIC", "d5/d62/industrytype_8h.html#a061cabddf1f472aa0b20fc1c827b1a34af38d617281bde4c932c9a619a4139239", null ],
      [ "INDUSTRYLIFE_PROCESSING", "d5/d62/industrytype_8h.html#a061cabddf1f472aa0b20fc1c827b1a34ad429852440e79494b179398af252c4dc", null ]
    ] ],
    [ "IndustryTileSpecialFlags", "d5/d62/industrytype_8h.html#aadb6ea2392665d0dbfbb5312aefc4d19", [
      [ "INDTILE_SPECIAL_NONE", "d5/d62/industrytype_8h.html#aadb6ea2392665d0dbfbb5312aefc4d19a8ba82525183f560a7486fc60b5397cf3", null ],
      [ "INDTILE_SPECIAL_NEXTFRAME_RANDOMBITS", "d5/d62/industrytype_8h.html#aadb6ea2392665d0dbfbb5312aefc4d19a40581de7e4bf4d6f0ec62ca368202f81", null ],
      [ "INDTILE_SPECIAL_ACCEPTS_ALL_CARGO", "d5/d62/industrytype_8h.html#aadb6ea2392665d0dbfbb5312aefc4d19a204390cf556bf6c21156f27592a0fbb9", null ]
    ] ],
    [ "GetIndustrySpec", "d5/d62/industrytype_8h.html#ac6d08ad30175d25c77a0d02c1e58ea04", null ],
    [ "GetIndustryTileSpec", "d5/d62/industrytype_8h.html#a3ac10016afb519146ebec380c135eb50", null ],
    [ "GetTranslatedIndustryTileID", "d5/d62/industrytype_8h.html#a6a79e4a7a18338817070046a8cfe983a", null ],
    [ "ResetIndustries", "d5/d62/industrytype_8h.html#a9e66870ad473f6a09ac310a185e463c9", null ],
    [ "SortIndustryTypes", "d5/d62/industrytype_8h.html#af8e88d4cf3f2021b94c3b4ffaf47d58d", null ],
    [ "_industry_specs", "d5/d62/industrytype_8h.html#a879ce65535fcae4f063356f59c2f8902", null ],
    [ "_industry_tile_specs", "d5/d62/industrytype_8h.html#a185ba06cc0018e2b2644371686652d67", null ],
    [ "_sorted_industry_types", "d5/d62/industrytype_8h.html#a3e15c4bfdb0b87c21f4487f603c3e5a0", null ],
    [ "IT_INVALID", "d5/d62/industrytype_8h.html#a8883e327c2f4a2520d739d0c7c50760c", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/d5/d62/industrytype_8h.js <==
var industrytype_8h =
[
    [ "IndustryTileLayoutTile", "da/d35/structIndustryTileLayoutTile.html", "da/d35/structIndustryTileLayoutTile" ],
    [ "IndustrySpec", "db/d4c/structIndustrySpec.html", "db/d4c/structIndustrySpec" ],
    [ "IndustryTileSpec", "d9/d21/structIndustryTileSpec.html", "d9/d21/structIndustryTileSpec" ],
    [ "IndustryTileLayout", "d5/d62/industrytype_8h.html#a7beed9c4ab49b441a3dd445e2759f236", null ],
    [ "CheckProc", "d5/d62/industrytype_8h.html#a54363dfab2318e7d24fa83b0666b312b", [
      [ "CHECK_NOTHING", "d5/d62/industrytype_8h.html#a54363dfab2318e7d24fa83b0666b312bacc607ecdcaf7ac10836498ac1c32b6fc", null ],
      [ "CHECK_FOREST", "d5/d62/industrytype_8h.html#a54363dfab2318e7d24fa83b0666b312baaaea95595ada9815e80802a632392164", null ],
      [ "CHECK_REFINERY", "d5/d62/industrytype_8h.html#a54363dfab2318e7d24fa83b0666b312ba058481b5fe16cad7dae9af8aa23db022", null ],
      [ "CHECK_FARM", "d5/d62/industrytype_8h.html#a54363dfab2318e7d24fa83b0666b312bab7c5bb91757770d4bbc113689faedc70", null ],
      [ "CHECK_PLANTATION", "d5/d62/industrytype_8h.html#a54363dfab2318e7d24fa83b0666b312ba0b84b07949e9dd6da3cb755e8daa63c6", null ],
      [ "CHECK_WATER", "d5/d62/industrytype_8h.html#a54363dfab2318e7d24fa83b0666b312ba7a22197324a2bbae6b3234445c149d68", null ],
      [ "CHECK_LUMBERMILL", "d5/d62/industrytype_8h.html#a54363dfab2318e7d24fa83b0666b312ba73090eaa29a15f6776c0b76cd525d62a", null ],
      [ "CHECK_BUBBLEGEN", "d5/d62/industrytype_8h.html#a54363dfab2318e7d24fa83b0666b312ba9829645d52d8361f20f26ce6f329e66d", null ],
      [ "CHECK_OIL_RIG", "d5/d62/industrytype_8h.html#a54363dfab2318e7d24fa83b0666b312ba3271c3e72eefaac6d8a43a782732b1d2", null ],
      [ "CHECK_END", "d5/d62/industrytype_8h.html#a54363dfab2318e7d24fa83b0666b312ba0b35eb6fd6cfa60b8000413f5962dd26", null ]
    ] ],
    [ "IndustryBehaviour", "d5/d62/industrytype_8h.html#a99a00afbb745b5044eadcb3211e8e2f9", [
      [ "INDUSTRYBEH_NONE", "d5/d62/industrytype_8h.html#a99a00afbb745b5044eadcb3211e8e2f9a5cc5dba847782c7648a951c34bc593d0", null ],
      [ "INDUSTRYBEH_PLANT_FIELDS", "d5/d62/industrytype_8h.html#a99a00afbb745b5044eadcb3211e8e2f9a76dde7b7f789ec2009577aa97c14ff3e", null ],
      [ "INDUSTRYBEH_CUT_TREES", "d5/d62/industrytype_8h.html#a99a00afbb745b5044eadcb3211e8e2f9a6d58133a80e93e1df5af1da431c713f8", null ],
      [ "INDUSTRYBEH_BUILT_ONWATER", "d5/d62/industrytype_8h.html#a99a00afbb745b5044eadcb3211e8e2f9a72a2551a3aebb49f26b79c4082444919", null ],
      [ "INDUSTRYBEH_TOWN1200_MORE", "d5/d62/industrytype_8h.html#a99a00afbb745b5044eadcb3211e8e2f9a907ddb055343a0f53899bf5cde042698", null ],
      [ "INDUSTRYBEH_ONLY_INTOWN", "d5/d62/industrytype_8h.html#a99a00afbb745b5044eadcb3211e8e2f9a9c81cbddfddaf0014021ec17ed4ea125", null ],
      [ "INDUSTRYBEH_ONLY_NEARTOWN", "d5/d62/industrytype_8h.html#a99a00afbb745b5044eadcb3211e8e2f9a8c2180317b5afe82e96461252c77fbbf", null ],
      [ "INDUSTRYBEH_PLANT_ON_BUILT", "d5/d62/industrytype_8h.html#a99a00afbb745b5044eadcb3211e8e2f9a406a478ad0065a3ac1bc7bcce6c39d7d", null ],
      [ "INDUSTRYBEH_DONT_INCR_PROD", "d5/d62/industrytype_8h.html#a99a00afbb745b5044eadcb3211e8e2f9a39109885917fedb779ff2a8a93aedd6c", null ],
      [ "INDUSTRYBEH_BEFORE_1950", "d5/d62/industrytype_8h.html#a99a00afbb745b5044eadcb3211e8e2f9aa050bdda302a8fad2713a5bb62577663", null ],
      [ "INDUSTRYBEH_AFTER_1960", "d5/d62/industrytype_8h.html#a99a00afbb745b5044eadcb3211e8e2f9a6abc825a855b53a48515a5d3e0a1bf01", null ],
      [ "INDUSTRYBEH_AI_AIRSHIP_ROUTES", "d5/d62/industrytype_8h.html#a99a00afbb745b5044eadcb3211e8e2f9ab62ae5c5a95e0377c6bfa2910c4cad9f", null ],
      [ "INDUSTRYBEH_AIRPLANE_ATTACKS", "d5/d62/industrytype_8h.html#a99a00afbb745b5044eadcb3211e8e2f9a1f43d132d3c437a41e80dbdaf2e8bd79", null ],
      [ "INDUSTRYBEH_CHOPPER_ATTACKS", "d5/d62/industrytype_8h.html#a99a00afbb745b5044eadcb3211e8e2f9a2f157fd12c1e0c258cc70ab4a0f6a7cf", null ],
      [ "INDUSTRYBEH_CAN_SUBSIDENCE", "d5/d62/industrytype_8h.html#a99a00afbb745b5044eadcb3211e8e2f9a0347d41faf719458cfa73c39eab6a2c7", null ],
      [ "INDUSTRYBEH_PROD_MULTI_HNDLING", "d5/d62/industrytype_8h.html#a99a00afbb745b5044eadcb3211e8e2f9a0237a5e8759779257383a9f21673ef34", null ],
      [ "INDUSTRYBEH_PRODCALLBACK_RANDOM", "d5/d62/industrytype_8h.html#a99a00afbb745b5044eadcb3211e8e2f9a5c8855dc4b542e13ad6fb1262d1f223f", null ],
      [ "INDUSTRYBEH_NOBUILT_MAPCREATION", "d5/d62/industrytype_8h.html#a99a00afbb745b5044eadcb3211e8e2f9adee9047f79a24111a338955e2ec2bb02", null ],
      [ "INDUSTRYBEH_CANCLOSE_LASTINSTANCE", "d5/d62/industrytype_8h.html#a99a00afbb745b5044eadcb3211e8e2f9a8403a7641291b2a97cbf819f605e79f6", null ],
      [ "INDUSTRYBEH_CARGOTYPES_UNLIMITED", "d5/d62/industrytype_8h.html#a99a00afbb745b5044eadcb3211e8e2f9a4f7c1634fba42ab82a3547a591171be2", null ],
      [ "INDUSTRYBEH_NO_PAX_PROD_CLAMP", "d5/d62/industrytype_8h.html#a99a00afbb745b5044eadcb3211e8e2f9a55819b9c6642d98b32b9e7a219b5693a", null ]
    ] ],
    [ "IndustryCleanupType", "d5/d62/industrytype_8h.html#a27c1fa18b6703e4d2c30dc686af62178", [
      [ "CLEAN_RANDOMSOUNDS", "d5/d62/industrytype_8h.html#a27c1fa18b6703e4d2c30dc686af62178a421b15b0bf55b443317d203ac6e89dc3", null ]
    ] ],
    [ "IndustryConstructionType", "d5/d62/industrytype_8h.html#a40770aa0e81a963e9e68382bbeea78f0", [
      [ "ICT_UNKNOWN", "d5/d62/industrytype_8h.html#a40770aa0e81a963e9e68382bbeea78f0a087b3ea80e3cbe71eb40d01e67a0cf29", null ],
      [ "ICT_NORMAL_GAMEPLAY", "d5/d62/industrytype_8h.html#a40770aa0e81a963e9e68382bbeea78f0a4cfe1db4597262af6495f9ad991f5299", null ],
      [ "ICT_MAP_GENERATION", "d5/d62/industrytype_8h.html#a40770aa0e81a963e9e68382bbeea78f0a38cc494ebad39e571b0bb076c7a5dad9", null ],
      [ "ICT_SCENARIO_EDITOR", "d5/d62/industrytype_8h.html#a40770aa0e81a963e9e68382bbeea78f0aa81941c1ebe098b7f56d5738ba7c55af", null ]
    ] ],
    [ "IndustryLifeType", "d5/d62/industrytype_8h.html#a061cabddf1f472aa0b20fc1c827b1a34", [
      [ "INDUSTRYLIFE_BLACK_HOLE", "d5/d62/industrytype_8h.html#a061cabddf1f472aa0b20fc1c827b1a34accef54b0e1b27f14e41048ab775ae8f1", null ],
      [ "INDUSTRYLIFE_EXTRACTIVE", "d5/d62/industrytype_8h.html#a061cabddf1f472aa0b20fc1c827b1a34a744b53cf47148684f40de047a727ef1e", null ],
      [ "INDUSTRYLIFE_ORGANIC", "d5/d62/industrytype_8h.html#a061cabddf1f472aa0b20fc1c827b1a34af38d617281bde4c932c9a619a4139239", null ],
      [ "INDUSTRYLIFE_PROCESSING", "d5/d62/industrytype_8h.html#a061cabddf1f472aa0b20fc1c827b1a34ad429852440e79494b179398af252c4dc", null ]
    ] ],
    [ "IndustryTileSpecialFlags", "d5/d62/industrytype_8h.html#aadb6ea2392665d0dbfbb5312aefc4d19", [
      [ "INDTILE_SPECIAL_NONE", "d5/d62/industrytype_8h.html#aadb6ea2392665d0dbfbb5312aefc4d19a8ba82525183f560a7486fc60b5397cf3", null ],
      [ "INDTILE_SPECIAL_NEXTFRAME_RANDOMBITS", "d5/d62/industrytype_8h.html#aadb6ea2392665d0dbfbb5312aefc4d19a40581de7e4bf4d6f0ec62ca368202f81", null ],
      [ "INDTILE_SPECIAL_ACCEPTS_ALL_CARGO", "d5/d62/industrytype_8h.html#aadb6ea2392665d0dbfbb5312aefc4d19a204390cf556bf6c21156f27592a0fbb9", null ]
    ] ],
    [ "GetIndustrySpec", "d5/d62/industrytype_8h.html#ac6d08ad30175d25c77a0d02c1e58ea04", null ],
    [ "GetIndustryTileSpec", "d5/d62/industrytype_8h.html#a3ac10016afb519146ebec380c135eb50", null ],
    [ "GetTranslatedIndustryTileID", "d5/d62/industrytype_8h.html#a6a79e4a7a18338817070046a8cfe983a", null ],
    [ "ResetIndustries", "d5/d62/industrytype_8h.html#a9e66870ad473f6a09ac310a185e463c9", null ],
    [ "SortIndustryTypes", "d5/d62/industrytype_8h.html#af8e88d4cf3f2021b94c3b4ffaf47d58d", null ],
    [ "_industry_specs", "d5/d62/industrytype_8h.html#a879ce65535fcae4f063356f59c2f8902", null ],
    [ "_industry_tile_specs", "d5/d62/industrytype_8h.html#a185ba06cc0018e2b2644371686652d67", null ],
    [ "_sorted_industry_types", "d5/d62/industrytype_8h.html#a97d2018ed36e3d81c61eb4b5db9aed4f", null ],
    [ "IT_INVALID", "d5/d62/industrytype_8h.html#a8883e327c2f4a2520d739d0c7c50760c", null ]
];
